@@ -72,6 +72,7 @@ where
     /// let p = p2d(2, 3);
     /// assert_eq!(bb2d(2..3, 3..4), BBox2d::from_point(p));
     /// ```
+    #[deprecated = "Use `from` instead."]
     pub fn from_point(p: Point<S, V>) -> BBox<S, V> {
         BBox { min: p, max: p }
     }
@@ -117,7 +118,7 @@ where
     {
         let mut iter = ii.into_iter();
         if let Some(p0) = iter.next() {
-            let mut bbox = BBox::from_point(*p0);
+            let mut bbox = BBox::from(*p0);
             for p in iter {
                 bbox = bbox.extend_to(*p);
             }
@@ -401,71 +402,6 @@ where
     }
 }
 
-fn to_range_inclusive<S, R>(r: R) -> RangeInclusive<S>
-where
-    S: Integer,
-    R: RangeBounds<S>,
-{
-    let start = match r.start_bound() {
-        Bound::Included(s) => *s,
-        Bound::Excluded(s) => *s + S::one(),
-        Bound::Unbounded => panic!("unbounded ranges are not allowed"),
-    };
-    let end = match r.end_bound() {
-        Bound::Included(s) => *s,
-        Bound::Excluded(s) => *s - S::one(),
-        Bound::Unbounded => panic!("unbounded ranges are not allowed"),
-    };
-    assert!(start <= end);
-    start..=end
-}
-
-/// Creates a 2d bounding box from ranges of x and y coordinates.
-pub fn bb2d<S, RX, RY>(rx: RX, ry: RY) -> BBox2d<S>
-where
-    S: Integer,
-    RX: RangeBounds<S>,
-    RY: RangeBounds<S>,
-{
-    let rx = to_range_inclusive(rx);
-    let ry = to_range_inclusive(ry);
-    let min = p2d(*rx.start(), *ry.start());
-    let max = p2d(*rx.end(), *ry.end());
-    BBox { min, max }
-}
-/// Creates a 3d bounding box from ranges of x, y and z coordinates.
-pub fn bb3d<S, RX, RY, RZ>(rx: RX, ry: RY, rz: RZ) -> BBox3d<S>
-where
-    S: Integer,
-    RX: RangeBounds<S>,
-    RY: RangeBounds<S>,
-    RZ: RangeBounds<S>,
-{
-    let rx = to_range_inclusive(rx);
-    let ry = to_range_inclusive(ry);
-    let rz = to_range_inclusive(rz);
-    let min = p3d(*rx.start(), *ry.start(), *rz.start());
-    let max = p3d(*rx.end(), *ry.end(), *rz.end());
-    BBox { min, max }
-}
-/// Creates a 4d bounding box from ranges of x, y, z and w coordinates.
-pub fn bb4d<S, RX, RY, RZ, RW>(rx: RX, ry: RY, rz: RZ, rw: RW) -> BBox4d<S>
-where
-    S: Integer,
-    RX: RangeBounds<S>,
-    RY: RangeBounds<S>,
-    RZ: RangeBounds<S>,
-    RW: RangeBounds<S>,
-{
-    let rx = to_range_inclusive(rx);
-    let ry = to_range_inclusive(ry);
-    let rz = to_range_inclusive(rz);
-    let rw = to_range_inclusive(rw);
-    let min = p4d(*rx.start(), *ry.start(), *rz.start(), *rw.start());
-    let max = p4d(*rx.end(), *ry.end(), *rz.end(), *rw.end());
-    BBox { min, max }
-}
-
 impl<S> BBox3d<S>
 where
     S: Integer,
@@ -708,6 +644,82 @@ where
     }
 }
 
+fn to_range_inclusive<S, R>(r: R) -> RangeInclusive<S>
+where
+    S: Integer,
+    R: RangeBounds<S>,
+{
+    let start = match r.start_bound() {
+        Bound::Included(s) => *s,
+        Bound::Excluded(s) => *s + S::one(),
+        Bound::Unbounded => panic!("unbounded ranges are not allowed"),
+    };
+    let end = match r.end_bound() {
+        Bound::Included(s) => *s,
+        Bound::Excluded(s) => *s - S::one(),
+        Bound::Unbounded => panic!("unbounded ranges are not allowed"),
+    };
+    assert!(start <= end);
+    start..=end
+}
+
+/// Creates a 2d bounding box from ranges of x and y coordinates.
+pub fn bb2d<S, RX, RY>(rx: RX, ry: RY) -> BBox2d<S>
+where
+    S: Integer,
+    RX: RangeBounds<S>,
+    RY: RangeBounds<S>,
+{
+    let rx = to_range_inclusive(rx);
+    let ry = to_range_inclusive(ry);
+    let min = p2d(*rx.start(), *ry.start());
+    let max = p2d(*rx.end(), *ry.end());
+    BBox { min, max }
+}
+/// Creates a 3d bounding box from ranges of x, y and z coordinates.
+pub fn bb3d<S, RX, RY, RZ>(rx: RX, ry: RY, rz: RZ) -> BBox3d<S>
+where
+    S: Integer,
+    RX: RangeBounds<S>,
+    RY: RangeBounds<S>,
+    RZ: RangeBounds<S>,
+{
+    let rx = to_range_inclusive(rx);
+    let ry = to_range_inclusive(ry);
+    let rz = to_range_inclusive(rz);
+    let min = p3d(*rx.start(), *ry.start(), *rz.start());
+    let max = p3d(*rx.end(), *ry.end(), *rz.end());
+    BBox { min, max }
+}
+/// Creates a 4d bounding box from ranges of x, y, z and w coordinates.
+pub fn bb4d<S, RX, RY, RZ, RW>(rx: RX, ry: RY, rz: RZ, rw: RW) -> BBox4d<S>
+where
+    S: Integer,
+    RX: RangeBounds<S>,
+    RY: RangeBounds<S>,
+    RZ: RangeBounds<S>,
+    RW: RangeBounds<S>,
+{
+    let rx = to_range_inclusive(rx);
+    let ry = to_range_inclusive(ry);
+    let rz = to_range_inclusive(rz);
+    let rw = to_range_inclusive(rw);
+    let min = p4d(*rx.start(), *ry.start(), *rz.start(), *rw.start());
+    let max = p4d(*rx.end(), *ry.end(), *rz.end(), *rw.end());
+    BBox { min, max }
+}
+
+impl<S, V> From<Point<S, V>> for BBox<S, V>
+where
+    S: Integer,
+    V: Vector<S>,
+{
+    /// Returns the bounding box which contains a single point.
+    fn from(p: Point<S, V>) -> BBox<S, V> {
+        BBox { min: p, max: p }
+    }
+}
+
 impl<S> IntoIterator for BBox<S, Vec2d<S>>
 where
     S: Integer,
@@ -797,6 +809,8 @@ where
 
 #[cfg(test)]
 mod tests {
+    use core::ops::Bound::Excluded;
+
     use crate::bb2d;
     use crate::bb3d;
     use crate::bb4d;
@@ -820,6 +834,7 @@ mod tests {
     }
 
     #[test]
+    #[allow(deprecated)]
     fn test_from_point() {
         let bb = BBox2d::from_point(p2d(-2, 3));
         assert_eq!(bb2d(-2..=-2, 3..=3), bb);
@@ -1282,6 +1297,52 @@ mod tests {
         assert_eq!(p4d(-1, 0, 3, -4), bb.random_point(&mut rng));
     }
 
+    #[test]
+    fn test_bb2d_incl() {
+        let bb = bb2d(0..=2, 1..=4);
+        assert_eq!(bb2d(0..3, 1..5), bb)
+    }
+    #[test]
+    fn test_bb2d_excl() {
+        let bb = bb2d((Excluded(-1), Excluded(3)), (Excluded(0), Excluded(5)));
+        assert_eq!(bb2d(0..3, 1..5), bb)
+    }
+    #[test]
+    fn test_bb3d_incl() {
+        let bb = bb3d(0..=2, 1..=4, 2..=6);
+        assert_eq!(bb3d(0..3, 1..5, 2..7), bb)
+    }
+    #[test]
+    fn test_bb3d_excl() {
+        let bb = bb3d(
+            (Excluded(-1), Excluded(3)),
+            (Excluded(0), Excluded(5)),
+            (Excluded(1), Excluded(7)),
+        );
+        assert_eq!(bb3d(0..3, 1..5, 2..7), bb)
+    }
+    #[test]
+    fn test_bb4d_incl() {
+        let bb = bb4d(0..=2, 1..=4, 2..=6, 3..=8);
+        assert_eq!(bb4d(0..3, 1..5, 2..7, 3..9), bb)
+    }
+    #[test]
+    fn test_bb4d_excl() {
+        let bb = bb4d(
+            (Excluded(-1), Excluded(3)),
+            (Excluded(0), Excluded(5)),
+            (Excluded(1), Excluded(7)),
+            (Excluded(2), Excluded(9)),
+        );
+        assert_eq!(bb4d(0..3, 1..5, 2..7, 3..9), bb)
+    }
+
+    #[test]
+    fn test_from() {
+        let bb = BBox2d::from(p2d(-2, 3));
+        assert_eq!(bb2d(-2..=-2, 3..=3), bb);
+    }
+
     #[test]
     fn test_iter_2d() {
         let bb = bb2d(1..=2, -1..=0);
