@@ -1,4 +1,4 @@
-//! 4-dimensional vectors.
+//! 4d vectors.
 
 use core::cmp::Ordering;
 use core::fmt;
@@ -22,14 +22,14 @@ use crate::VectorOps;
 
 const DIM: usize = 4;
 
-/// A four-dimensional discrete vector.
+/// A 4d discrete vector.
 #[derive(Clone, Copy, Default, Eq, PartialEq, Hash)]
 pub struct Vec4d<S = i64>([S; DIM])
 where
     S: Integer;
 
 impl<S: Integer> Vec4d<S> {
-    /// Creates a new 4d-vector from its coordinates.
+    /// Creates a new 4d vector from its coordinates.
     pub fn new(x: S, y: S, z: S, w: S) -> Vec4d<S> {
         Vec4d([x, y, z, w])
     }
@@ -253,25 +253,6 @@ impl<S: Integer> Vector<S> for Vec4d<S> {
         self * self
     }
 
-    /// Creates a vector of the 80 vectors with L∞ norm equal to 1.
-    fn unit_vecs_l_infty() -> Vec<Self> {
-        let mut result = Vec::new();
-        let zero = S::zero();
-        let one = S::one();
-        for w in [-one, zero, one] {
-            for z in [-one, zero, one] {
-                for y in [-one, zero, one] {
-                    for x in [-one, zero, one] {
-                        if x != zero || y != zero || z != zero || w != zero {
-                            result.push(v4d(x, y, z, w));
-                        }
-                    }
-                }
-            }
-        }
-        result
-    }
-
     fn componentwise_cmp(&self, other: &Vec4d<S>) -> Option<Ordering> {
         let x_ordering = Some(self.x().cmp(&other.x()));
         let y_ordering = Some(self.y().cmp(&other.y()));
@@ -295,7 +276,7 @@ impl<S: Integer> Vector<S> for Vec4d<S> {
     }
 }
 
-/// Creates a 4d-vector.
+/// Creates a 4d vector.
 ///
 /// This is a utility function for concisely representing vectors.
 pub fn v4d<S: Integer>(x: S, y: S, z: S, w: S) -> Vec4d<S> {
@@ -560,7 +541,7 @@ mod tests {
 
     #[test]
     fn test_unit_vecs() {
-        let mut uv: Vec<Vec4d<i64>> = Vec4d::unit_vecs();
+        let mut uv = Vec4d::unit_vecs().collect::<Vec<Vec4d<i64>>>();
         uv.sort_by(Vec4d::lex_cmp);
         assert_eq!(
             vec![
@@ -575,7 +556,7 @@ mod tests {
 
     #[test]
     fn test_unit_vecs_l1() {
-        let mut uv: Vec<Vec4d<i64>> = Vec4d::unit_vecs_l1();
+        let mut uv = Vec4d::unit_vecs_l1().collect::<Vec<Vec4d<i64>>>();
         uv.sort_by(Vec4d::lex_cmp);
         assert_eq!(
             vec![
@@ -594,7 +575,7 @@ mod tests {
 
     #[test]
     fn test_unit_vecs_l_infty() {
-        let mut uv: Vec<Vec4d<i64>> = Vec4d::unit_vecs_l_infty();
+        let mut uv = Vec4d::unit_vecs_l_infty().collect::<Vec<Vec4d<i64>>>();
         uv.sort_by(Vec4d::lex_cmp);
         assert_eq!(
             vec![
